"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = Accordion;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _react = _interopRequireWildcard(require("react"));

/**
 * Accordion which only allows one child `ExpandableSection` to be open at a time
 *
 * ```js
 *  <Accordion>
 *    <ExpandableSection title="First">
 *      <div>The first section</div>
 *    </ExpandableSection>
 *    <ExpandableSection title="Second">
 *      <div>The second section</div>
 *    </ExpandableSection>
 *    <ExpandableSection title="Third">
 *      <div>The third section</div>
 *    </ExpandableSection>
 *  </Accordion>
 * ```
 */
function Accordion(_ref) {
  var children = _ref.children;

  if (!children) {
    return null;
  }

  var _useState = (0, _react.useState)(function () {
    return children.findIndex(function (child) {
      return child.props.expanded;
    });
  }),
      _useState2 = (0, _slicedToArray2["default"])(_useState, 2),
      expanded = _useState2[0],
      setExpanded = _useState2[1];

  return (
    /*#__PURE__*/
    // wrapped in a Fragment so react-docgen recognizes this as a Component:
    _react["default"].createElement(_react["default"].Fragment, null, _react["default"].Children.map(children, function (child, i) {
      return /*#__PURE__*/_react["default"].cloneElement(child, {
        expanded: expanded === i,
        onChange: function onChange(e, expanded) {
          e.preventDefault();
          setExpanded(expanded ? i : null);
        }
      });
    }))
  );
}

Accordion.propTypes = {
  /**
   * A list of `ExpandableSection`s that will be controlled.
   */
  children: _propTypes["default"].node
};
//# sourceMappingURL=Accordion.js.map