"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = withCaching;

/**
 * Creates a cancelable event handler that will run unless the provided
 * handler calls `e.preventDefault()`.
 *
 * @param {Function} handler The original event handle supplied to the component
 * @param {Number} maxAgeSeconds The time in seconds that a result should be kept in the service worker cache.
 * @return {Function}
 */
function withCaching(handler, maxAgeSeconds) {
  return function (req, res) {
    if (maxAgeSeconds) {
      res.setHeader('x-sw-cache-control', "max-age: ".concat(maxAgeSeconds));
    }

    return handler(req, res);
  };
}
//# sourceMappingURL=withCaching.js.map